import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Label, Loader } from '@ui5/webcomponents-react';
import { useStylesheet } from '@ui5/webcomponents-react-base';
import { clsx } from 'clsx';
import { Component, forwardRef } from 'react';
import { ResponsiveContainer } from 'recharts';
import { classNames, styleData } from './ChartContainer.module.css.js';
const loaderStyles = {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0
};
class ErrorBoundary extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            errorCount: 0
        };
    }
    componentDidCatch() {
        if (this.state.errorCount < 3) {
            this.setState((old) => ({ ...old, errorCount: old.errorCount + 1 }));
        }
    }
    render() {
        if (this.state.errorCount >= 3) {
            return _jsx(Label, { children: "Sorry, something went wrong while rendering this chart!" });
        }
        return this.props.children;
    }
}
const ChartContainer = forwardRef((props, ref) => {
    const { Placeholder, loading = false, dataset, className, slot, children, resizeDebounce, ...rest } = props;
    useStylesheet(styleData, ChartContainer.displayName);
    return (_jsx("div", { ref: ref, className: clsx(classNames.container, className), slot: slot, ...rest, children: dataset?.length > 0 ? (_jsxs(_Fragment, { children: [loading && _jsx(Loader, { style: loaderStyles }), _jsx(ErrorBoundary, { children: _jsx(ResponsiveContainer, { debounce: resizeDebounce, children: children }) })] })) : (_jsx(Placeholder, {})) }));
});
ChartContainer.displayName = 'ChartContainer';
export { ChartContainer };
